#region ... Copyright  2004 Roland Weigelt ...
/*
DragHandleSplitter Control -- Copyright  2004 Roland Weigelt

Warranty

	This software is supplied "AS IS".  The author disclaims all
	warranties, expressed or implied, including, without limitation,
	the warranties of merchantability and of fitness for any purpose.
	The author assumes no liability for direct, indirect, incidental,
	special, exemplary, or consequential damages, which may result
	from the use of this software, even if advised of the possibility
	of such damage.

Terms of Use

	Permission is hereby granted to use, copy, modify, and distribute
	the source code, or portions hereof, without fee, subject to the
	following restrictions:

	- The origin of the source code must not be misrepresented.
	- Altered versions must be plainly marked as such and must not
	  be misrepresented as being the original source.
	- The copyright notice may not be removed or altered from any
	  source or altered source distribution.
*/
#endregion

using System;
using System.Windows.Forms;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;

namespace Weigelt.Windows.Forms
{
	/// <summary>
	/// Enhanced splitter control with a handle for dragging the splitter.
	/// </summary>
	public class DragHandleSplitter : System.Windows.Forms.Splitter
	{
		private const int _SplitterThickness=6;
		private const int _HandleThickness=5; // LightLight + Light + Control + Dark + DarkDark
		private const int _HandleLength=16;

		private void DrawRectangle(Graphics g, int x1, int y1, int x2, int y2, Color lightColor, Color darkColor)
		{
			using (Pen penDark=new Pen(darkColor))
			using (Pen penLight=new Pen(lightColor))
			{
				g.DrawLine(penLight, x1, y1, x1, y2); // Left
				g.DrawLine(penDark, x1, y2, x2, y2); // Bottom
				g.DrawLine(penDark, x2, y1, x2, y2); // Right
				g.DrawLine(penLight, x1, y1, x2, y1); // Top
			}
		}

		/// <summary>
		/// Called when the control is resized. Raises the
		/// <see cref="System.Windows.Forms.Control.Resize"/> event.
		/// </summary>
		/// <param name="e"></param>
		protected override void OnResize(EventArgs e)
		{
			switch (this.Dock)
			{
				case DockStyle.Left:
				case DockStyle.Right:
					base.Width=_SplitterThickness;
					break;
				case DockStyle.Top:
				case DockStyle.Bottom:
					base.Height=_SplitterThickness;
					break;
			}
			base.OnResize(e);
			this.Invalidate(); // we've got to redraw with every resize
		}

		/// <summary>
		/// Called for painting the control; this is where the drag
		/// handle is painted.
		/// </summary>
		/// <param name="pevent"></param>
		protected override void OnPaint(PaintEventArgs pevent)
		{
			base.OnPaint(pevent);

			int nHandleWidth=_HandleLength;
			int nHandleHeight=_HandleThickness;
			if ((this.Dock==DockStyle.Left) || (this.Dock==DockStyle.Right))
			{
				// Swap if docked to the left or right;
				nHandleWidth=_HandleThickness;
				nHandleHeight=_HandleLength;
			}

			int nHandleX1=(this.Width/2)-(nHandleWidth/2);
			int nHandleX2=nHandleX1+nHandleWidth-1;
			int nHandleY1=(this.Height/2)-(nHandleHeight/2);
			int nHandleY2=nHandleY1+nHandleHeight-1;

			DrawRectangle(pevent.Graphics, nHandleX1+1, nHandleY1+1, nHandleX2-1, nHandleY2-1, SystemColors.ControlLight, SystemColors.ControlDark);
			DrawRectangle(pevent.Graphics, nHandleX1, nHandleY1, nHandleX2, nHandleY2, SystemColors.ControlLightLight, SystemColors.ControlDarkDark);
		}

		#region ... Constructor ...

		/// <summary>
		/// Creates a new <see cref="DragHandleSplitter"/> instance.
		/// </summary>
		public DragHandleSplitter()
		{
			this.Dock=DockStyle.Top;
		}

		#endregion
	}
}
